@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "config.h"
@@ -26,7 +26,7 @@
 #include <unistd.h>
 #include <errno.h>
 
-#include "board.h"
+#include "board-gtk.h"
 #include "playfield.h"
 #include "main.h"
 #include "goal.h"
@@ -61,101 +61,57 @@ static void game_init (void);
 static void update_statistics (void);
 static void view_congratulations (void);
 static void calculate_score (void);
-static void log_score (void);
 
 /* ===============================================================
       
              Menu callback  functions 
 
 -------------------------------------------------------------- */
-static void verb_GameNew_cb (BonoboUIComponent *uic, gpointer user_data,
-			     const char *cname)
+static void verb_GameNew_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
   controller_handle_action (GAME_ACTION_NEW);
 }
 
-static void verb_GameEnd_cb (BonoboUIComponent * uic, gpointer user_data,
-			     const char *cname)
+static void verb_GameEnd_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
   controller_handle_action (GAME_ACTION_END);
 }
 
-static void verb_GameSkip_cb (BonoboUIComponent * uic, gpointer user_data,
-			      const char *cname)
+static void verb_GameSkip_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
   controller_handle_action (GAME_ACTION_SKIP);
 }
 
-static void verb_GameReset_cb (BonoboUIComponent * uic, gpointer user_data,
-			       const char *cname)
+static void verb_GameReset_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
   controller_handle_action (GAME_ACTION_RESTART);
 }
 
-static void verb_GamePause_cb (BonoboUIComponent * uic, gpointer user_data,
-			       const char *cname)
+static void verb_GamePause_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
   controller_handle_action (GAME_ACTION_PAUSE);
 }
 
-static void verb_GameContinue_cb (BonoboUIComponent * uic,
-				  gpointer user_data, const char *cname)
+static void verb_GameContinue_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
   controller_handle_action (GAME_ACTION_CONTINUE);
 }
 
-static void verb_GameUndo_cb (BonoboUIComponent * uic, gpointer user_data,
-			      const char *cname)
+static void verb_GameUndo_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
   controller_handle_action (GAME_ACTION_UNDO);
 }
 
-static void verb_GameScores_cb (BonoboUIComponent * uic, gpointer user_data,
-				const char *cname)
-{
-  struct stat scores_file;
-
-  stat (SCORESDIR "/atomix.scores", &scores_file);
-
-  if (scores_file.st_size == 0)
-    {
-      GtkWidget *dlg = gtk_message_dialog_new (GTK_WINDOW (app->mainwin),
-					       GTK_DIALOG_MODAL,
-					       GTK_MESSAGE_INFO,
-					       GTK_BUTTONS_CLOSE,
-					       _("You have not achieved any "
-						 "scores yet. Play a little "
-						 "before coming back!"));
-      gtk_dialog_run (GTK_DIALOG (dlg));
-      gtk_widget_destroy (GTK_WIDGET (dlg));
-
-      return;
-    }
-
-  gnome_scores_display ("Atomix", PACKAGE, NULL, 0);
-}
-
-static void verb_GameExit_cb (BonoboUIComponent * uic, gpointer user_data,
-			      const char *cname)
+static void verb_GameExit_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
   atomix_exit ();
 }
 
-static void verb_EditPreferences_cb (BonoboUIComponent * uic,
-				     gpointer user_data, const char *cname)
+static void verb_HelpAbout_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
-#if 0
-  preferences_show_dialog ();
-#endif
-}
-
-static void verb_HelpAbout_cb (BonoboUIComponent *uic, gpointer user_data,
-			       const char *cname)
-{
-  GtkWidget *dlg;
-
   const char *authors[] =
     {
+      "Robert Roth <robert.roth.off@gmail.com>",
       "Guilherme de S. Pastore <gpastore@gnome.org>",
       "Jens Finke <jens@triq.net>",
       NULL
@@ -167,16 +123,17 @@ static void verb_HelpAbout_cb (BonoboUIComponent *uic, gpointer user_data,
       NULL
     };
 
-  dlg = gtk_about_dialog_new ();
-  gtk_about_dialog_set_name (GTK_ABOUT_DIALOG(dlg), "Atomix");
-  gtk_about_dialog_set_version (GTK_ABOUT_DIALOG(dlg), VERSION);
-  gtk_about_dialog_set_comments (GTK_ABOUT_DIALOG(dlg), _("A puzzle game about atoms and molecules"));
-  gtk_about_dialog_set_website (GTK_ABOUT_DIALOG(dlg), "http://www.gnome.org/projects/atomix");
-  gtk_about_dialog_set_authors (GTK_ABOUT_DIALOG(dlg), authors);
-  gtk_about_dialog_set_artists (GTK_ABOUT_DIALOG(dlg), artists);
-  gtk_about_dialog_set_translator_credits (GTK_ABOUT_DIALOG(dlg), _("translator-credits"));
 
-  gtk_widget_show (dlg);
+  gtk_show_about_dialog(GTK_WINDOW(app->mainwin),
+  					"program-name", _("Atomix"),
+					"logo-icon-name", "atomix",
+  					"version", VERSION,
+  					"comments", _("A puzzle game about atoms and molecules"),
+  					"website", "https://github.com/GNOME/atomix",
+  					"authors", authors,
+  					"artists", artists,
+  					"translator_credits", _("translator-credits"),
+  					NULL);
 }
 
 static gboolean on_app_destroy_event (GtkWidget *widget, GdkEvent *event,
@@ -215,14 +172,13 @@ static void controller_handle_action (GameAction action)
       switch (action)
 	{
 	case GAME_ACTION_END:
-	  log_score ();
 	  level_cleanup_view ();
 	  set_game_not_running_state ();
 	  break;
 
 	case GAME_ACTION_PAUSE:
 	  clock_stop (CLOCK (app->clock));
-	  board_hide ();
+	  board_gtk_hide ();
 	  app->state = GAME_STATE_PAUSED;
 	  break;
 
@@ -242,7 +198,6 @@ static void controller_handle_action (GameAction action)
 	  if (level_manager_is_last_level (app->lm, app->level))
 	    {
 	      view_congratulations ();
-	      log_score ();
 	      level_cleanup_view ();
 	      set_game_not_running_state ();
 	    }
@@ -264,9 +219,11 @@ static void controller_handle_action (GameAction action)
 	case GAME_ACTION_UNDO:
 	  g_assert (app->state != GAME_STATE_RUNNING_UNMOVED);
 
-	  board_undo_move ();
+	  board_gtk_undo_move ();
 	  break;
 
+	case GAME_ACTION_NEW:
+	case GAME_ACTION_CONTINUE:
 	default:
 	  break;
 	}
@@ -275,8 +232,8 @@ static void controller_handle_action (GameAction action)
     case GAME_STATE_PAUSED:
       if (action == GAME_ACTION_CONTINUE)
 	{
-	  clock_start (CLOCK(app->clock));
-	  board_show ();
+	  clock_resume (CLOCK(app->clock));
+	  board_gtk_show ();
 	  app->state = (undo_exists())?GAME_STATE_RUNNING:GAME_STATE_RUNNING_UNMOVED;
 	}
       break;
@@ -291,7 +248,7 @@ static void controller_handle_action (GameAction action)
 
 static void set_game_not_running_state (void)
 {
-  board_show_logo (TRUE);
+  board_gtk_show_logo (TRUE);
 
   if (app->level)
     g_object_unref (app->level);
@@ -354,14 +311,14 @@ static void setup_level (void)
   /* init board */
   env_pf = level_get_environment (app->level);
   sce_pf = level_get_scenario (app->level);
-  board_show_logo (FALSE);
-  board_init_level (env_pf, sce_pf, app->goal);
+  board_gtk_show_logo (FALSE);
+  board_gtk_init_level (env_pf, sce_pf, app->goal);
 
   /* init goal */
   goal_view_render (app->goal);
 
   /* init clock */
-  clock_set_seconds (CLOCK(app->clock), 0);
+  clock_reset (CLOCK(app->clock));
   clock_start (CLOCK(app->clock));
 
   g_object_unref (env_pf);
@@ -370,7 +327,7 @@ static void setup_level (void)
 
 static void level_cleanup_view (void)
 {
-  board_clear ();
+  board_gtk_clear ();
   goal_view_clear ();
 
   clock_stop (CLOCK(app->clock));
@@ -386,11 +343,10 @@ static void atomix_exit (void)
 
   if (app->state != GAME_STATE_NOT_RUNNING)
     {
-      log_score ();
       set_game_not_running_state ();
     }
 
-  board_destroy ();
+  board_gtk_destroy ();
 
   if (app->level)
     g_object_unref (app->level);
@@ -405,10 +361,8 @@ static void atomix_exit (void)
     g_object_unref (app->tm);
 
   /* quit application */
-  bonobo_object_unref (BONOBO_OBJECT (app->ui_component));
   gtk_widget_destroy (app->mainwin);
 
-  gtk_main_quit ();
 }
 
 static gboolean on_key_press_event (GObject *widget, GdkEventKey *event,
@@ -416,13 +370,13 @@ static gboolean on_key_press_event (GObject *widget, GdkEventKey *event,
 {
   if ((app->state == GAME_STATE_RUNNING) || (app->state == GAME_STATE_RUNNING_UNMOVED))
     {
-      board_handle_key_event (NULL, event, NULL);
+      return board_gtk_handle_key_event (NULL, event, NULL);
     }
 
-  return TRUE;
+  return FALSE;
 }
 
-static void game_init ()
+static void game_init (void)
 {
   g_return_if_fail (app != NULL);
 
@@ -441,20 +395,20 @@ static void game_init ()
   app->level_no = 0;
   app->score = 0;
   clock_set_format (CLOCK(app->clock), "%M:%S");
-  clock_set_seconds (CLOCK(app->clock), 0);
+  clock_reset (CLOCK(app->clock));
 
   /* init the board */
-  board_init (app->theme, GNOME_CANVAS (app->ca_matrix));
+  board_gtk_init (app->theme, GTK_FIXED (app->fi_matrix));
 
   /* init goal */
-  goal_view_init (app->theme, GNOME_CANVAS (app->ca_goal));
+  goal_view_init (app->theme, GTK_FIXED (app->fi_goal));
 
   /* update user visible information */
   app->state = GAME_STATE_NOT_RUNNING;
   update_menu_item_state ();
   update_statistics ();
 
-  gtk_widget_grab_focus (GTK_WIDGET (app->ca_matrix));
+  gtk_widget_grab_focus (GTK_WIDGET (app->fi_matrix));
 }
 
 void game_level_finished (void)
@@ -464,9 +418,7 @@ void game_level_finished (void)
 
 static void calculate_score (void)
 {
-  gint seconds;
-
-  seconds = time (NULL) - CLOCK(app->clock)->seconds;
+  gint seconds = clock_get_elapsed (CLOCK (app->clock));
 
   if (seconds > 300)
     return;
@@ -477,17 +429,6 @@ static void calculate_score (void)
     app->score = app->score * (2 - (seconds / 300));
 }
 
-static void log_score (void)
-{
-  gint position;
-
-  if (app->score == 0)
-    return;
-
-  position = gnome_score_log (app->score, NULL, TRUE);
-  gnome_scores_display (_("Atomix"), PACKAGE, NULL, position);
-}
-
 static void view_congratulations (void)
 {
   GtkWidget *dlg;
@@ -501,19 +442,6 @@ static void view_congratulations (void)
   gtk_widget_destroy (GTK_WIDGET (dlg));
 }
 
-#if 0
-dlg = gtk_message_dialog_new (GTK_WINDOW (app->mainwin),
-			      GTK_DIALOG_MODAL,
-			      GTK_MESSAGE_ERROR,
-			      GTK_BUTTONS_OK,
-			      "%s", _("Couldn't find at least one level."));
-gtk_dialog_run (GTK_DIALOG (dlg));
-gtk_widget_destroy (GTK_WIDGET (dlg));
-
-
-_("Do you want to finish the game?"));
-#endif
-
 /* ===============================================================
       
              UI update functions
@@ -562,10 +490,28 @@ static void update_statistics (void)
 
 typedef struct
 {
-  gchar *cmd;
+  const gchar *cmd;
   gboolean enabled;
 } CmdEnable;
 
+
+static const GActionEntry app_entries[] =
+  {
+    { "GameAbout", verb_HelpAbout_cb, NULL, NULL, NULL},
+    { "GameQuit", verb_GameExit_cb, NULL, NULL, NULL}
+  };
+
+static const GActionEntry win_entries[] =
+  {
+    { "GameNew", verb_GameNew_cb, NULL, NULL, NULL},
+    { "GameEnd", verb_GameEnd_cb, NULL, NULL, NULL},
+    { "GameSkip", verb_GameSkip_cb, NULL, NULL, NULL},
+    { "GameReset", verb_GameReset_cb, NULL, NULL, NULL},
+    { "GameUndo", verb_GameUndo_cb, NULL, NULL, NULL},
+    { "GamePause", verb_GamePause_cb, NULL, NULL, NULL},
+    { "GameContinue", verb_GameContinue_cb, NULL, NULL, NULL},
+  };
+
 static const CmdEnable not_running[] =
   {
     { "GameNew",      TRUE  },
@@ -575,7 +521,6 @@ static const CmdEnable not_running[] =
     { "GameUndo",     FALSE },
     { "GamePause",    FALSE },
     { "GameContinue", FALSE },
-    { "EditPreferences", TRUE },
     { NULL, FALSE }
   };
 
@@ -588,7 +533,6 @@ static const CmdEnable running_unmoved[] =
     { "GameUndo",     FALSE },
     { "GamePause",    TRUE  },
     { "GameContinue", FALSE },
-    { "EditPreferences", TRUE },
     { NULL, FALSE }
 };
 
@@ -601,7 +545,6 @@ static const CmdEnable running[] =
     { "GameUndo",     TRUE  },
     { "GamePause",    TRUE  },
     { "GameContinue", FALSE },
-    { "EditPreferences", TRUE },
     { NULL, FALSE }
 };
 
@@ -614,7 +557,6 @@ static const CmdEnable paused[] =
     { "GameUndo",     FALSE },
     { "GamePause",    FALSE },
     { "GameContinue", TRUE  },
-    { "EditPreferences", TRUE },
     { NULL, FALSE }
 };
 
@@ -625,16 +567,14 @@ static const CmdEnable *state_sensitivity[] =
 
 void update_menu_item_state (void)
 {
-  gchar *path;
   gint i;
   const CmdEnable *cmd_list = state_sensitivity[app->state];
+  GAction *action;
 
   for (i = 0; cmd_list[i].cmd != NULL; i++)
     {
-      path = g_strconcat ("/commands/", cmd_list[i].cmd, NULL);
-      bonobo_ui_component_set_prop (app->ui_component, path, "sensitive",
-				    cmd_list[i].enabled ? "1" : "0", NULL);
-      g_free (path);
+      action = g_action_map_lookup_action (G_ACTION_MAP (app->mainwin), cmd_list[i].cmd);
+      g_simple_action_set_enabled (G_SIMPLE_ACTION (action), cmd_list[i].enabled);
     }
 }
 
@@ -643,185 +583,101 @@ void update_menu_item_state (void)
              GUI creation  functions 
 
 -------------------------------------------------------------- */
-static BonoboUIVerb verbs[] =
-  {
-    BONOBO_UI_VERB ("GameNew", verb_GameNew_cb),
-    BONOBO_UI_VERB ("GameEnd", verb_GameEnd_cb),
-    BONOBO_UI_VERB ("GameSkip", verb_GameSkip_cb),
-    BONOBO_UI_VERB ("GameReset", verb_GameReset_cb),
-    BONOBO_UI_VERB ("GameUndo", verb_GameUndo_cb),
-    BONOBO_UI_VERB ("GamePause", verb_GamePause_cb),
-    BONOBO_UI_VERB ("GameContinue", verb_GameContinue_cb),
-    BONOBO_UI_VERB ("GameScores", verb_GameScores_cb),
-    BONOBO_UI_VERB ("GameExit", verb_GameExit_cb),
-    BONOBO_UI_VERB ("EditPreferences", verb_EditPreferences_cb),
-#if 0
-    BONOBO_UI_VERB ("HelpManual", verb_HelpManual_cb),
-#endif
-    BONOBO_UI_VERB ("HelpAbout", verb_HelpAbout_cb), BONOBO_UI_VERB_END
-  };
-
-static GtkWidget *create_canvas_widget (GtkWidget **canvas)
+static AtomixApp *create_gui (GApplication *app_instance)
 {
-  GtkWidget *frame;
-
-  *canvas = gnome_canvas_new_aa ();
-
-  frame = gtk_frame_new (NULL);
-  gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
-  gtk_container_add (GTK_CONTAINER (frame), GTK_WIDGET (*canvas));
-
-  return frame;
-}
-
-static void add_statistics_table_entry (GtkWidget *table, gint row,
-					gchar *label_str, gboolean is_clock,
-					GtkWidget **return_widget)
-{
-  GtkWidget *label;
-  GtkWidget *lb_align;
-  GtkWidget *align;
-
-  label = gtk_label_new (label_str);
-  lb_align = gtk_alignment_new (1.0, 0.5, 0.0, 0.0);
-  gtk_container_add (GTK_CONTAINER (lb_align), GTK_WIDGET (label));
-  gtk_table_attach (GTK_TABLE (table), GTK_WIDGET (lb_align),
-		    0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
-
-  if (is_clock)
-    *return_widget = clock_new ();
-  else
-    *return_widget = gtk_label_new ("NO CONTENT");
-
-  align = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
-  gtk_container_add (GTK_CONTAINER (align), GTK_WIDGET (*return_widget));
-  gtk_table_attach (GTK_TABLE (table), GTK_WIDGET (align),
-		    1, 2, row, row + 1, GTK_FILL, GTK_FILL, 6, 0);
-}
-
-static GtkWidget *create_mainwin_content (AtomixApp *app)
-{
-  GtkWidget *hbox;
-  GtkWidget *vbox;
-  GtkWidget *pf;
-  GtkWidget *goal;
-  GtkWidget *frame;
-  GtkWidget *table;
-
-  /* create canvas widgets */
-  pf = create_canvas_widget (&app->ca_matrix);
-  goal = create_canvas_widget (&app->ca_goal);
-  gtk_widget_set_size_request (GTK_WIDGET (goal), 180, 50);
-
-  /* add playfield canvas to left side */
-  hbox = gtk_hbox_new (FALSE, 6);
-  gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
-  gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (pf), TRUE, TRUE, 0);
-  g_signal_connect (G_OBJECT (app->ca_matrix), "key_press_event",
-		    G_CALLBACK (on_key_press_event), app);
-
-  /* create right window side */
-  vbox = gtk_vbox_new (FALSE, 6);
-  gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (vbox), FALSE, TRUE, 0);
-
-  /* create statistics frame */
-  frame = gtk_frame_new (_("Statistics"));
-  table = gtk_table_new (4, 2, FALSE);
-  gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-  gtk_table_set_col_spacings (GTK_TABLE (table), 6);
-  gtk_container_set_border_width (GTK_CONTAINER (table), 6);
-
-  add_statistics_table_entry (table, 0, _("Level:"), FALSE, &app->lb_level);
-  add_statistics_table_entry (table, 1, _("Molecule:"), FALSE, &app->lb_name);
-  add_statistics_table_entry (table, 2, _("Formula:"), FALSE, &app->lb_formula);
-  add_statistics_table_entry (table, 3, _("Score:"), FALSE, &app->lb_score);
-  add_statistics_table_entry (table, 4, _("Time:"), TRUE, &app->clock);
-
-  gtk_container_add (GTK_CONTAINER (frame), GTK_WIDGET (table));
-
-  /* add frame and goal canvas to left side */
-  gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (frame), FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (goal), TRUE, TRUE, 0);
-
-  /* show all */
-  gtk_widget_show_all (GTK_WIDGET (hbox));
-  return hbox;
-}
-
-static AtomixApp *create_gui (GnomeProgram *prog)
-{
-  AtomixApp *app;
-  gchar *ui_file = NULL;
-
-  GtkWidget *content;
+  gchar *ui_path;
+  GtkBuilder *builder;
+  GtkWidget *stats_grid;
+  GtkWidget *time_label;
 
   app = g_new0 (AtomixApp, 1);
-  app->prog = prog;
   app->level = NULL;
+  app->app_instance = app_instance;
+
+  builder = gtk_builder_new ();
+
+  ui_path = g_build_filename (PKGDATADIR, "ui", "interface.ui", NULL);
+  gtk_builder_add_from_file (builder, ui_path, NULL);
+  g_free (ui_path);
+
+  app->mainwin = GTK_WIDGET (gtk_builder_get_object (builder, "mainwin"));
 
-  app->mainwin = bonobo_window_new ("atomix", "Atomix");
   g_signal_connect (G_OBJECT (app->mainwin), "delete_event",
-		    (GCallback) on_app_destroy_event, app);
+                    (GCallback) on_app_destroy_event, app);
 
-  app->ui_container =
-    bonobo_ui_engine_get_ui_container (bonobo_window_get_ui_engine
-				       (BONOBO_WINDOW (app->mainwin)));
+  /* create canvas widgets */
+  app->fi_matrix = GTK_WIDGET (gtk_builder_get_object (builder, "game_fixed"));
+  app->fi_goal = GTK_WIDGET (gtk_builder_get_object (builder, "preview_fixed"));
 
-  app->ui_component = bonobo_ui_component_new ("atomix");
-  bonobo_ui_component_set_container (app->ui_component,
-				     BONOBO_OBJREF (app->ui_container), NULL);
+  stats_grid = GTK_WIDGET (gtk_builder_get_object (builder, "stats_grid"));
+  time_label = GTK_WIDGET (gtk_builder_get_object (builder, "time_label"));
+  app->clock = clock_new ();
+  gtk_grid_attach_next_to (GTK_GRID (stats_grid), app->clock,
+                           time_label, GTK_POS_RIGHT, 1, 1);
 
-  /* find xml menu description */
-  ui_file = bonobo_ui_util_get_ui_fname (DATADIR, "atomix-ui.xml");
-  if (ui_file && !g_file_test (ui_file, G_FILE_TEST_EXISTS))
-    {
-      g_error (_("Couldn't find file: %s"), ui_file);
-      return NULL;
-    }
+  /* add playfield canvas to left side */
+  g_signal_connect (G_OBJECT (app->mainwin), "key-press-event",
+		    G_CALLBACK (on_key_press_event), app);
 
-  /* set menus */
-  bonobo_ui_util_set_ui (app->ui_component, "", ui_file, "atomix", NULL);
-  g_free (ui_file);
+  app->lb_level = GTK_WIDGET (gtk_builder_get_object (builder, "level_value"));
+  app->lb_name = GTK_WIDGET (gtk_builder_get_object (builder, "molecule_value"));
+  app->lb_formula = GTK_WIDGET (gtk_builder_get_object (builder, "formula_value"));
+  app->lb_score = GTK_WIDGET (gtk_builder_get_object (builder, "score_value"));
 
-  bonobo_ui_component_add_verb_list_with_data (app->ui_component, verbs, app);
+  gtk_widget_show_all (GTK_WIDGET (app->mainwin));
 
-  /* create window contents */
-  content = create_mainwin_content (app);
 
-  gtk_window_set_default_icon_from_file (g_build_filename (DATADIR,
-							   "pixmaps",
-							   "atomix-icon.png",
-							   NULL),
-					 NULL);
+  if (gtk_application_prefers_app_menu (GTK_APPLICATION (app_instance))) {
+    GMenu * menu = G_MENU (gtk_builder_get_object (builder, "app-menu"));
+    gtk_application_set_app_menu (GTK_APPLICATION (app->app_instance), G_MENU_MODEL (menu));
+//    GtkWidget *menubar = GTK_WIDGET (gtk_builder_get_object (builder, "menubar"));
+//    gtk_widget_set_visible (menubar, FALSE);
+  }
 
-  gtk_widget_show (GTK_WIDGET (content));
-
-  bonobo_window_set_contents (BONOBO_WINDOW (app->mainwin), content);
+  g_object_unref (builder);
 
   return app;
 }
 
+static void
+app_activate (GApplication *app_instance, gpointer user_data)
+{
+
+  if (app == NULL) {
+    /* make a few initalisations here */
+    g_action_map_add_action_entries (G_ACTION_MAP (app_instance), app_entries, G_N_ELEMENTS (app_entries), app_instance);
+
+    app = create_gui (app_instance);
+    g_action_map_add_action_entries (G_ACTION_MAP (app->mainwin), win_entries, G_N_ELEMENTS (win_entries), app_instance);
+
+    game_init ();
+    gtk_widget_set_size_request (GTK_WIDGET (app->mainwin), 678, 520);
+
+    //gtk_window_set_resizable (GTK_WINDOW (app->mainwin), FALSE);
+    gtk_widget_show (app->mainwin);
+    gtk_application_add_window (GTK_APPLICATION (app_instance), GTK_WINDOW (app->mainwin));
+  } else {
+    gtk_window_present (GTK_WINDOW (app->mainwin));
+  }
+}
+
 int main (int argc, char *argv[])
 {
-  GnomeProgram *prog;
+  GtkApplication *gtk_app;
 
-  gnome_score_init (PACKAGE);
+  int status;
+
+  g_set_application_name (_("Atomix"));
 
   bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  prog = gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
-			     argc, argv, NULL);
+  gtk_app = gtk_application_new ("org.gnome.atomix", G_APPLICATION_FLAGS_NONE);
+  g_signal_connect (gtk_app, "activate", G_CALLBACK (app_activate), NULL);
 
-  /* make a few initalisations here */
-  app = create_gui (prog);
+  status = g_application_run (G_APPLICATION (gtk_app), argc, argv);
+  g_object_unref (gtk_app);
 
-  game_init ();
-
-  gtk_widget_set_size_request (GTK_WIDGET (app->mainwin), 660, 480);
-  gtk_widget_show (app->mainwin);
-
-  gtk_main ();
-  return 0;
+  return status;
 }
